==> chaosmesh-model-5.0.3-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodNetworkChaosListFluent<A extends PodNetworkChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,PodNetworkChaos item);
    public A setToItems(int index,PodNetworkChaos item);
    public A addToItems(PodNetworkChaos... items);
    public A addAllToItems(Collection<PodNetworkChaos> items);
    public A removeFromItems(PodNetworkChaos... items);
    public A removeAllFromItems(Collection<PodNetworkChaos> items);
    public A removeMatchingFromItems(Predicate<PodNetworkChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodNetworkChaos> getItems();
    public List<PodNetworkChaos> buildItems();
    public PodNetworkChaos buildItem(int index);
    public PodNetworkChaos buildFirstItem();
    public PodNetworkChaos buildLastItem();
    public PodNetworkChaos buildMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public A withItems(List<PodNetworkChaos> items);
    public A withItems(PodNetworkChaos... items);
    public Boolean hasItems();
    public PodNetworkChaosListFluent.ItemsNested<A> addNewItem();
    public PodNetworkChaosListFluent.ItemsNested<A> addNewItemLike(PodNetworkChaos item);
    public PodNetworkChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodNetworkChaos item);
    public PodNetworkChaosListFluent.ItemsNested<A> editItem(int index);
    public PodNetworkChaosListFluent.ItemsNested<A> editFirstItem();
    public PodNetworkChaosListFluent.ItemsNested<A> editLastItem();
    public PodNetworkChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodNetworkChaosFluent<PodNetworkChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodNetworkChaosListFluent<A extends PodNetworkChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,PodNetworkChaos item);
    public A setToItems(int index,PodNetworkChaos item);
    public A addToItems(PodNetworkChaos... items);
    public A addAllToItems(Collection<PodNetworkChaos> items);
    public A removeFromItems(PodNetworkChaos... items);
    public A removeAllFromItems(Collection<PodNetworkChaos> items);
    public A removeMatchingFromItems(Predicate<PodNetworkChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodNetworkChaos> getItems();
    public List<PodNetworkChaos> buildItems();
    public PodNetworkChaos buildItem(int index);
    public PodNetworkChaos buildFirstItem();
    public PodNetworkChaos buildLastItem();
    public PodNetworkChaos buildMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public A withItems(List<PodNetworkChaos> items);
    public A withItems(PodNetworkChaos... items);
    public Boolean hasItems();
    public PodNetworkChaosListFluent.ItemsNested<A> addNewItem();
    public PodNetworkChaosListFluent.ItemsNested<A> addNewItemLike(PodNetworkChaos item);
    public PodNetworkChaosListFluent.ItemsNested<A> setNewItemLike(int index,PodNetworkChaos item);
    public PodNetworkChaosListFluent.ItemsNested<A> editItem(int index);
    public PodNetworkChaosListFluent.ItemsNested<A> editFirstItem();
    public PodNetworkChaosListFluent.ItemsNested<A> editLastItem();
    public PodNetworkChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<PodNetworkChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodNetworkChaosFluent<PodNetworkChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
